@@ -1,10 +1,10 @@
-/* $Id: cctmkind.c,v 1.4 2005/04/11 01:27:44 zlb Exp $ */
+/* $Id: cctmkind.c,v 1.5 2005/05/23 06:41:05 zlb Exp $ */
 
 /* Makeindex for CCT */
 
 typedef unsigned char byte;
 
-#define version "0.0.4"
+#define version "0.0.5"
 
 #include <stdio.h>
 #include <string.h>
@@ -169,7 +169,7 @@ do_remove_blancs(byte **str)
 static void
 parse_actual(byte **item, byte **key)
 {
-    byte *p;
+    byte *p, *q;
 
     if (*item != NULL) {
 	if ((p = find_unquoted_char(*item, actual)) != NULL) {
@@ -184,6 +184,24 @@ parse_actual(byte **item, byte **key)
     do_remove_quotes(key);
     do_remove_quotes(item);
 
+    if (*key != NULL && GBK_get_ordering() == GBK_MIXED) {
+fprintf(stderr, "old key = %s\n", *key);
+	p = *key;
+	q = buffer;
+	while (*p != '\0') {
+	    while (*p < 128 && *p != '\0') *(q++) = *(p++);
+	    if (*p == '\0') break;
+	    if (q > buffer) *(q++) = ' ';
+	    GBK_get_initial(q, sizeof(buffer) - (q - buffer), p);
+	    p += 2;
+	    while (*q != '\0') q++;
+	}
+	*q = '\0';
+	free(*key);
+	*key = strdup(buffer);
+fprintf(stderr, "new key = %s\n", *key);
+    }
+
     if (remove_blancs) {
 	do_remove_blancs(key);
 	do_remove_blancs(item);
@@ -800,7 +818,8 @@ main(int argc, char *argv[])
 	   ERROR((stderr, "  -p num	defines starting page number.\n"));
 	   ERROR((stderr, "  -q		suppresses verbose messages.\n"));
 	   ERROR((stderr, "Other options:\n"));
-	   ERROR((stderr, "  -C sort	ordering ('pinyin' or 'stroke').\n"));
+	   ERROR((stderr, "  -C sort	order of Chinese characters "
+			  "('pinyin', 'stroke' or 'mixed').\n"));
 	   ERROR((stderr, "  -h		shows this help message.\n"));
 	   ERROR((stderr, "Options '-irgLT' and '-t log' are ignored.\n"));
 	   return 1;
@@ -836,6 +855,8 @@ main(int argc, char *argv[])
 		    GBK_set_ordering(GBK_PINYIN);
 		else if (!stricmp(argv[i+1], "stroke"))
 		    GBK_set_ordering(GBK_STROKE);
+		else if (!stricmp(argv[i+1], "mixed"))
+		    GBK_set_ordering(GBK_MIXED);
 		else goto error;
 		i++;
 		break;
